/**
 * Addierer-Operationsverst&auml;rker.
 * 
 * @author Owyn
 * @version 2008-06-08
 */
public class AdderOpAmp extends IdealOpAmp {
    
    /**
     * Eingangswiderstand 2
     */
    protected double inputResistor2;
    
    /**
     * Erzeugt einen Operationsverst&auml;rker, bei dem alle Widerst&auml;nde 1 sind.
     */
    public AdderOpAmp() {
        super();
        inputResistor2 = 1.0;
    }
    
    /**
     * Erzeugt einen Operationsverst&auml;rker.
     * 
     * @param inputResistor1 Erster Eingangswiderstand
     * @param inputResistor2 Zweiter Eingangswiderstand
     * @param outputResistor Ausgangswiderstand
     */
    public AdderOpAmp(double inputResistor1, double inputResistor2, double outputResistor) {
        super(inputResistor1, outputResistor);
        this.inputResistor2 = inputResistor2;
    }
    
    /**
     * Berechnet die Ausgangsspannung zu zwei Eingangsspannungen.
     * 
     * @param input1 Erste Eingangsspannung
     * @param input2 Zweite Eingangsspannung
     * @return Ausgangsspannung
     */
    public double computeOutput(double input1, double input2) {
        return -((inputResistor / outputResistor) * input1 + (inputResistor2 / outputResistor) * input2);
    }
    
    /**
     * Gibt die Daten des Operationsverst&auml;rkers als String zur&uuml;ck.
     *
     * @return Kennung und Widerstandswerte
     */
    public String toString() {
        return "AdderOpAmp - RI1: " + inputResistor + ", RI2: " + inputResistor2 + ", RO: " + outputResistor;
    }
    
    /**
     * Testet, ob sich der Operationsverst&auml;rkers im Addierer-Modus befindet
     *
     * @return true, wenn Addierer-Modus, sonst false
     */
    public boolean adderMode() {
        return (inputResistor == outputResistor) && (inputResistor == inputResistor2);
    }
    
}