/**
 * Idealer Operationsverst&auml;rker.
 * 
 * @author Owyn
 * @version 2008-06-08
 */
public class IdealOpAmp {
    
    /**
     * Eingangswiderstand
     */
    protected double inputResistor;
    /**
     * Ausgangswiderstand
     */
    protected double outputResistor;
    
    /**
     * Erzeugt einen Operationsverst&auml;rker, bei dem Eingangs- und Ausgangswiderstand 1 sind.
     */
    public IdealOpAmp() {
        inputResistor = 1.0;
        outputResistor = 1.0;
    }
    
    /**
     * Erzeugt einen Operationsverst&auml;rker.
     * 
     * @param inputResistor Eingangswiderstand
     * @param outputResistor Ausgangswiderstand
     */
    public IdealOpAmp(double inputResistor, double outputResistor) {
        this.inputResistor = inputResistor;
        this.outputResistor = outputResistor;
    }
    
    /**
     * Berechnet die Ausgangsspannung zu einer Eingangsspannung.
     * 
     * @param input Eingangsspannung
     * @return Ausgangsspannung
     */
    public double computeOutput(double input) {
        return -((inputResistor / outputResistor) * input);
    }
    
    /**
     * Gibt die Daten des Operationsverst&auml;rkers als String zur&uuml;ck.
     *
     * @return Kennung und Widerstandswerte
     */
    public String toString() {
        return "IdealOpAmp - RI: " + inputResistor + ", RO: " + outputResistor;
    }
    
}